@@ -2,6 +2,7 @@ library(shiny)
 source("mappings.R")
 
 ui <- navbarPage(title = "Single-case effect size calculator",
+                 id = "SCD_es_calculator",
                  tabPanel("About",
                           navlistPanel(widths = c(3,9),
                                        tabPanel("About", 
@@ -60,6 +61,7 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                                                     "PEM",
                                                                     "PND",
                                                                     "Tau",
+                                                                    "Tau-BC" = "Tau_BC",
                                                                     "Tau-U" = "Tau_U"), 
                                                         selected = "NAP")
                                           ),
@@ -67,7 +69,7 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                             br(),
                                             selectInput("parametric_ES", 
                                                         label = "Effect size index", 
-                                                        choices = c("LOR", "LRRd", "LRRi","SMD"), 
+                                                        choices = c("LOR", "LRRd", "LRRi", "LRM", "SMD"), 
                                                         selected = "LRRd"),
                                             conditionalPanel(condition = "input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
                                                              checkboxInput("pct_change","Convert LRR to % change"))
@@ -76,6 +78,26 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                               selectInput("improvement",
                                           label = "Direction of improvement",
                                           choices = c("increase", "decrease")),
+                              conditionalPanel(condition = "input.ES_family=='Non-overlap' & input.NOM_ES == 'Tau_BC'",
+                                               radioButtons("tau_calculation",
+                                                            label = "Choose a method for calculating Tau index",
+                                                            choices = c("Tau (non-overlap)" = "Nlap",
+                                                                        "Kendall rank correlation" = "Kendall"))
+                              ),
+                              conditionalPanel(condition = "input.ES_family=='Non-overlap' & input.NOM_ES == 'Tau_BC'",
+                                               radioButtons("baseline_check",
+                                                            label = "Test for baseline trend",
+                                                            choices = c("Always adjust for baseline trend" = "No", 
+                                                                        "Pretest for baseline trend, adjust if significant" = "Yes"))
+                              ),
+                              conditionalPanel(condition = "input.ES_family=='Non-overlap' & 
+                                               input.NOM_ES == 'Tau_BC' & input.baseline_check == 'Yes'",
+                                               numericInput("significance_level", 
+                                                            label = "Significance level for the initial baseline trend test", 
+                                                            value = 0.05, step = .01,
+                                                            min = 0.01, 
+                                                            max = 0.99)
+                              ),
                               conditionalPanel("input.ES_family=='Parametric'",
                                  conditionalPanel(condition = "input.parametric_ES == 'SMD'",
                                                   radioButtons("SMD_denom", 
@@ -94,7 +116,7 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                  conditionalPanel(condition = "input.parametric_ES=='LOR'|input.parametric_ES=='LRRi'|input.parametric_ES=='LRRd'",
                                                   numericInput("lrrfloor", label = "User-specified floor constant",value = NULL))
                               ),
-                              conditionalPanel(condition = "input.ES_family=='Parametric'|input.NOM_ES=='NAP'|input.NOM_ES=='Tau'",
+                              conditionalPanel(condition = "input.ES_family=='Parametric'|input.NOM_ES=='NAP'|input.NOM_ES=='Tau'|input.NOM_ES=='Tau_BC'",
                                   numericInput("confidence", 
                                                label = "Confidence level", 
                                                value = 95, 
@@ -120,10 +142,12 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                                                         conditionalPanel("input.NOM_ES == 'PEM'", withMathJax(includeMarkdown("markdown/PEM.md"))),
                                                                         conditionalPanel("input.NOM_ES == 'PND'", withMathJax(includeMarkdown("markdown/PND.md"))),
                                                                         conditionalPanel("input.NOM_ES == 'Tau'", withMathJax(includeMarkdown("markdown/Tau.md"))),
+                                                                        conditionalPanel("input.NOM_ES == 'Tau_BC'", withMathJax(includeMarkdown("markdown/Tau-BC.md"))),
                                                                         conditionalPanel("input.NOM_ES == 'Tau_U'", withMathJax(includeMarkdown("markdown/Tau-U.md")))
                                                        ),
                                                        conditionalPanel("input.ES_family=='Parametric'",
                                                                         conditionalPanel("input.parametric_ES == 'LRRi'|input.parametric_ES == 'LRRd'", withMathJax(includeMarkdown("markdown/LRR.md"))),
+                                                                        conditionalPanel("input.parametric_ES == 'LRM'", withMathJax(includeMarkdown("markdown/LRM.md"))),
                                                                         conditionalPanel("input.parametric_ES == 'SMD'", withMathJax(includeMarkdown("markdown/SMD.md"))),
                                                                         conditionalPanel("input.parametric_ES == 'LOR'", withMathJax(includeMarkdown("markdown/LOR.md")))
                                                        )
@@ -134,9 +158,12 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                  ),
                  tabPanel("Batch Entry",
                           tabsetPanel(
+                            id = "BatchEntryTabs",
                             tabPanel("Data",
                                      sidebarLayout(sidebarPanel(radioButtons('dat_type', 'What data do you want to use?', 
-                                                                             c("Use an example" = "example", "Upload data from a file" = "dat")),
+                                                                             c("Use an example" = "example",
+                                                                               "Upload data from a .csv or .txt file" = "dat",
+                                                                               "Upload data from a .xlsx file" = "xlsx")),
                                                                 conditionalPanel(
                                                                   condition = "input.dat_type == 'example'",
                                                                   selectInput("example", label = "Choose an example", 
@@ -146,9 +173,18 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                                                   condition = "input.dat_type == 'dat'",
                                                                   fileInput('dat', 'Upload a .csv or .txt file', accept=c('text/csv', 'text/comma-separated-values,text/plain', '.csv', '.txt')),
                                                                   checkboxInput('header', 'File has a header?', TRUE),
-                                                                  radioButtons('sep', 'Data seperator', c(Commas=',', Semicolons=';', Tabs='\t', Spaces=' ')),
-                                                                  radioButtons('quote', 'Include quotes?', c('No'='', 'Double Quotes'='"', 'Single Quotes'="'"))
-                                                                )),
+                                                                  radioButtons('sep', 'Data seperator', c(Commas=',', Semicolons=';', Tabs='\t', Spaces=' '), inline = TRUE),
+                                                                  radioButtons('quote', 'Include quotes?', c('No'='', 'Double Quotes'='"', 'Single Quotes'="'"), inline = TRUE)
+                                                                ),
+                                                                conditionalPanel(
+                                                                  condition = "input.dat_type == 'xlsx'",
+                                                                  fileInput('xlsx', 'Upload a .xlsx file', accept = c('.xlsx')),
+                                                                  checkboxInput('col_names', 'File has a header?', TRUE),
+                                                                  selectInput("inSelect", "Select a sheet", "")
+                                                                ),
+                                                                uiOutput("filtervarMapping"),
+                                                                uiOutput("filterMapping")
+                                                                ),
                                                    mainPanel(tableOutput("datview")))
                                      ),
                             tabPanel("Variables",
@@ -160,17 +196,52 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                          uiOutput("treatDefine"),
                                          uiOutput("outOrderImp"),
                                          conditionalPanel(condition = "input.bimprovement == 'series'",
-                                                          uiOutput("improvementVar"))
+                                                          uiOutput("improvementVar")),
+                                         br(),
+                                         br(),
+                                         br()
                                        ),
                                        mainPanel(tableOutput("datview2"))
                                      )
                                      ),
+                            tabPanel("Plot",
+                                     sidebarLayout(
+                                       sidebarPanel(
+                                         style = "max-height: 800px; overflow-y: auto",
+                                         uiOutput("facetSelector"),
+                                         uiOutput("graph_filters"),
+                                         br(),
+                                         br(),
+                                         br(),
+                                         br()
+                                       ),
+                                       mainPanel(plotOutput('batchPlot', height = "auto"))
+                                       # mainPanel(tableOutput("datview3"))
+                                     )
+                                     
+                            ),
                             tabPanel("Estimate", 
                                      sidebarLayout(
                                        sidebarPanel(
                                          h4("Select Effect Sizes"),
-                                         checkboxGroupInput("bESno", "Non-Overlap Effect Sizes", choices = c("IRD","NAP","PAND","PEM","PND","Tau","Tau-U" = "Tau_U"), inline = TRUE),
-                                         checkboxGroupInput("bESpar", "Parametric Effect Sizes", choices = c("LOR", "LRRd", "LRRi" ,"SMD"),inline = TRUE),
+                                         checkboxGroupInput("bESno", "Non-Overlap Effect Sizes", choices = c("IRD","NAP","PAND","PEM","PND","Tau","Tau-BC" = "Tau_BC","Tau-U" = "Tau_U"), inline = TRUE),
+                                         checkboxGroupInput("bESpar", "Parametric Effect Sizes", choices = c("LOR", "LRRd", "LRRi", "LRM", "SMD"), inline = TRUE),
+                                         conditionalPanel(condition = "input.bESno.includes('Tau_BC')",
+                                                          radioButtons("btau_calculation", label = "Choose a method for calculating Tau index",
+                                                                       choices = c("Tau (non-overlap)" = "Nlap",
+                                                                                   "Kendall rank correlation" = "Kendall"),
+                                                                       inline = TRUE)),
+                                         conditionalPanel(condition = "input.bESno.includes('Tau_BC')",
+                                                          radioButtons("bbaseline_check", label = "Use baseline trend test for Tau-BC?",
+                                                                       choices = c("Always adjusting for baseline trend" = "No", 
+                                                                                   "Pretest for baseline trend, adjust if significant" = "Yes"), 
+                                                                       inline = FALSE)),
+                                         conditionalPanel(condition = "input.bESno.includes('Tau_BC') & input.bbaseline_check == 'Yes'",
+                                                          numericInput("bsignificance_level",
+                                                                       label = "Significance level for the baseline trend test",
+                                                                       value = 0.05, step = .01,
+                                                                       min = 0.01,
+                                                                       max = 0.99)),
                                          conditionalPanel(condition = "input.bESpar.includes('LRRi') | input.bESpar.includes('LRRd') | input.bESpar.includes('LOR')",
                                                           checkboxInput("b_pct_change", "Convert LRR to % change")),
                                          conditionalPanel(condition = "input.bESpar.includes('LOR')", 
@@ -180,6 +251,11 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                                                        choices = c("baseline SD" = "baseline", "pooled SD" = "pool"), inline = TRUE)),
                                          conditionalPanel(condition = "input.bESpar.includes('LRRi') | input.bESpar.includes('LRRd') | input.bESpar.includes('LOR')",
                                                           uiOutput("measurementProc")),
+                                         conditionalPanel(condition = "input.b_aggregate != ''", 
+                                                          radioButtons('weighting_scheme',
+                                                                       label = "Weighting scheme to use for aggregating.",
+                                                                       choices = c("equal", "1/V", "nA", "nB", "nA*nB", "1/nA + 1/nB"))
+                                                          ),
                                          numericInput("bconfidence", label = "Confidence level (for any effect size with standard errors)", value = 95, min = 0, max = 100),
                                          radioButtons("resultsformat", "Long or wide format?", c("Long" = "long", "Wide" = "wide"), inline = TRUE),
                                          conditionalPanel(condition = "input.bESpar.length > 0 || input.bESno.length > 0", 
@@ -196,6 +272,11 @@ ui <- navbarPage(title = "Single-case effect size calculator",
                                        )
                                     )
                                      
+                            ),
+                            tabPanel("Syntax for R",
+                                     rclipboard::rclipboardSetup(),
+                                     uiOutput("clip"),
+                                     verbatimTextOutput("syntax")
                             )
                           )
                           
