@@ -16,7 +16,7 @@ ES_long <-
 
 test_that("Long format works properly.", {
 
-  expect_identical(names(ES_long), c("ES","Est","SE","CI_lower","CI_upper"))
+  expect_identical(names(ES_long), c("ES","Est","SE","CI_lower","CI_upper", "baseline_SD"))
   expect_true(all(is.na(with(ES_long, SE[ES %in% c("IRD","PAND","PND","PEM","Tau-U")]))))
   expect_true(all(!is.na(with(ES_long, SE[ES %in% c("LRRd","LRRi","LOR","SMD","NAP","Tau", "Tau-BC")]))))
   expect_identical(ES_long$ES, sort(c("LRRd","LRRi","LOR","SMD","LRM","NAP","IRD","PAND","PND","PEM","Tau","Tau-U","Tau-BC")))
@@ -34,7 +34,7 @@ test_that("Wide format works for ES = 'all' when confidence is specified", {
     gather("q","v") %>%
     separate(q, into = c("ES","q"), sep = "_", extra = "merge") %>%
     spread(q, v, fill = NA) %>%
-    select(ES, Est, SE, CI_lower, CI_upper)
+    select(ES, Est, SE, CI_lower, CI_upper, ends_with("_SD"))
   
   expect_identical(ES_long, ES_to_long)
 })
@@ -58,20 +58,27 @@ test_that("Wide format works for ES = 'all', when confidence is NULL", {
 
 test_that("Wide format works for ES = 'parametric', when confidence is specified", {
   
+  parametric_long_pooled_SD <- 
+    calc_ES(
+      A_data = A_data, B_data = B_data, ES = "all", 
+      scale = "percentage", improvement = "decrease",
+      std_dev = "pooled", confidence = .90
+    ) %>%
+    arrange(ES) %>% 
+    dplyr::filter(ES %in% c("LOR","LRRd","LRRi","SMD","LRM"))
+  
   ES_wide <- calc_ES(A_data = A_data, B_data = B_data, ES = "parametric",
                      scale = "percentage", improvement = "decrease", 
-                     confidence = .90, format = "wide")
+                     std_dev = "pooled", confidence = .90, format = "wide")
   
   ES_to_long <- 
     ES_wide %>%
     gather("q","v") %>%
     separate(q, into = c("ES","q"), sep = "_", extra = "merge") %>%
     spread(q, v, fill = NA) %>%
-    select(ES, Est, SE, CI_lower, CI_upper)
+    select(ES, Est, SE, CI_lower, CI_upper, ends_with("_SD"))
   
-  parametric_long <- ES_long %>% dplyr::filter(ES %in% c("LOR","LRRd","LRRi","SMD","LRM"))
-  
-  expect_identical(parametric_long, ES_to_long)
+  expect_identical(parametric_long_pooled_SD, ES_to_long)
 })
 
 test_that("Wide format works for ES = 'parametric', when confidence is NULL", {
@@ -107,7 +114,10 @@ test_that("Wide format works for ES = 'NOM', when confidence is specified", {
     spread(q, v, fill = NA)  %>%
     select(ES, Est, SE, CI_lower, CI_upper)
   
-  NOM_long <- ES_long %>% dplyr::filter(ES %in% c("NAP","IRD","PAND","PND","PEM","Tau","Tau-U","Tau-BC"))
+  NOM_long <- 
+    ES_long %>% 
+    dplyr::filter(ES %in% c("NAP","IRD","PAND","PND","PEM","Tau","Tau-U","Tau-BC")) %>% 
+    dplyr::select(-ends_with("_SD"))
   
   expect_identical(NOM_long, ES_to_long)
 })
@@ -125,7 +135,10 @@ test_that("Wide format works for ES = 'NOM', when confidence is NULL", {
     separate(q, into = c("ES","q"), sep = "_", extra = "merge") %>%
     spread(q, v, fill = NA)
   
-  NOM_long <- ES_long %>% dplyr::filter(ES %in% c("NAP","IRD","PAND","PND","PEM","Tau","Tau-U","Tau-BC"))
+  NOM_long <- 
+    ES_long %>% 
+    dplyr::filter(ES %in% c("NAP","IRD","PAND","PND","PEM","Tau","Tau-U","Tau-BC")) %>% 
+    dplyr::select(-ends_with("_SD"))
   
   expect_identical(NOM_long$ES, ES_to_long$ES)
   expect_identical(NOM_long$Est, ES_to_long$Est)
